@@ -73,13 +73,13 @@
 // Danimo: Why do we use the old interface?!
 extern "C"
 {
-    KDE_EXPORT TDECModule *create_style(TQWidget *parent, const char*)
+    TDE_EXPORT TDECModule *create_style(TQWidget *parent, const char*)
     {
         TDEGlobal::locale()->insertCatalogue("kcmstyle");
         return new KCMStyle(parent, "kcmstyle");
     }
 
-    KDE_EXPORT void init_style()
+    TDE_EXPORT void init_style()
     {
         uint flags = KRdbExportQtSettings | KRdbExportQtColors | KRdbExportXftSettings;
         TDEConfig config("kcmdisplayrc", true /*readonly*/, false /*don't read kdeglobals etc.*/);
@@ -197,7 +197,7 @@ KCMStyle::KCMStyle( TQWidget* parent, const char* name )
 
 	m_popupMenuDelay = new KIntNumInput(250, gbWidgetStyle);
 	m_popupMenuDelay->setLabel(i18n("Menu popup delay:"));
-	m_popupMenuDelay->setRange(0, 5000, 50);
+	m_popupMenuDelay->setRange(0, 5000, 10);
 	m_popupMenuDelay->setSuffix(i18n(" msec"));
 	m_popupMenuDelay->setSteps(50, 50);
 	gbWidgetStyleLayout->addWidget(m_popupMenuDelay);
