@@ -48,7 +48,7 @@
 #include <kicondialog.h>
 #include <kdirselectdialog.h>
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
 #include <netwm.h>
 #endif
 
@@ -56,9 +56,9 @@
 
 using namespace std;
 
-#if defined(Q_WS_X11)
+#if defined(TQ_WS_X11)
 extern "C" { int XSetTransientForHint( Display *, unsigned long, unsigned long ); }
-#endif // Q_WS_X11
+#endif // TQ_WS_X11
 
 static TDECmdLineOptions options[] =
 {
@@ -125,10 +125,10 @@ bool WinIdEmbedder::eventFilter(TQObject *o, TQEvent *e)
     if (e->type() == TQEvent::Show && o->isWidgetType()
         && o->inherits("KDialog"))
     {
-        TQWidget *w = TQT_TQWIDGET(o);
+        TQWidget *w = static_cast<TQWidget*>(o);
         if (print)
             cout << "winId: " << w->winId() << endl;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
         if (id)
             XSetTransientForHint(w->x11Display(), w->winId(), id);
 #endif
@@ -301,11 +301,11 @@ static int directCommand(TDECmdLineArgs *args)
 						       0, // name
 						       duration );
 	TQTimer *timer = new TQTimer();
-	TQObject::connect( timer, TQT_SIGNAL( timeout() ), kapp, TQT_SLOT( quit() ) );
-	TQObject::connect( popup, TQT_SIGNAL( clicked() ), kapp, TQT_SLOT( quit() ) );
+	TQObject::connect( timer, TQ_SIGNAL( timeout() ), kapp, TQ_SLOT( quit() ) );
+	TQObject::connect( popup, TQ_SIGNAL( clicked() ), kapp, TQ_SLOT( quit() ) );
 	timer->start( duration, TRUE );
 
-#ifdef Q_WS_X11	
+#ifdef TQ_WS_X11	
 	if ( ! kapp->geometryArgument().isEmpty()) {
 	    int x, y;
 	    int w, h;
@@ -525,7 +525,7 @@ static int directCommand(TDECmdLineArgs *args)
         TQString startDir;
         startDir = TQString::fromLocal8Bit(args->getOption("getexistingdirectory"));
 	TQString result;
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 	result = TQFileDialog::getExistingDirectory(startDir, 0, "getExistingDirectory",
 							   title, true, true);
 #else
