@@ -27,7 +27,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <tqpopupmenu.h>
 
-class KDE_EXPORT TaskRMBMenu : public TQPopupMenu
+class TDE_EXPORT TaskRMBMenu : public TQPopupMenu
 {
 	TQ_OBJECT
 
@@ -38,9 +38,10 @@ public:
 private:
 	void fillMenu(Task::Ptr);
 	void fillMenu();
-    TQPopupMenu* makeAdvancedMenu(Task::Ptr);
+	TQPopupMenu* makeAdvancedMenu(Task::Ptr);
 	TQPopupMenu* makeDesktopsMenu(Task::Ptr);
 	TQPopupMenu* makeDesktopsMenu();
+	TQPopupMenu* makeTileMenu(Task::Ptr);
 
 private slots:
 	void slotMinimizeAll();
@@ -48,7 +49,7 @@ private slots:
 	void slotRestoreAll();
 	void slotShadeAll();
 	void slotCloseAll();
-	void slotAllToDesktop( int desktop );
+	void slotAllToDesktop(int desktop);
 	void slotAllToCurrentDesktop();
 
 private:
