@@ -95,7 +95,7 @@ KonqCombo::KonqCombo( TQWidget *parent, const char *name )
           : KHistoryCombo( parent, name ),
             m_returnPressed( false ), 
             m_permanent( false ),
-            m_modifier( Qt::NoButton ),
+            m_modifier( TQt::NoButton ),
 	    m_pageSecurity( KonqMainWindow::NotCrypted )
 {
     setInsertionPolicy( NoInsertion );
@@ -122,14 +122,14 @@ KonqCombo::KonqCombo( TQWidget *parent, const char *name )
     // Make the lineedit consume the Key_Enter event...
     setTrapReturnKey( true );
 
-    connect( KonqHistoryManager::kself(), TQT_SIGNAL(cleared()), TQT_SLOT(slotCleared()) );
-    connect( this, TQT_SIGNAL(cleared() ), TQT_SLOT(slotCleared()) );
-    connect( this, TQT_SIGNAL(highlighted( int )), TQT_SLOT(slotSetIcon( int )) );
-    connect( this, TQT_SIGNAL(activated( const TQString& )),
-             TQT_SLOT(slotActivated( const TQString& )) );
+    connect( KonqHistoryManager::kself(), TQ_SIGNAL(cleared()), TQ_SLOT(slotCleared()) );
+    connect( this, TQ_SIGNAL(cleared() ), TQ_SLOT(slotCleared()) );
+    connect( this, TQ_SIGNAL(highlighted( int )), TQ_SLOT(slotSetIcon( int )) );
+    connect( this, TQ_SIGNAL(activated( const TQString& )),
+             TQ_SLOT(slotActivated( const TQString& )) );
 
     setHistoryEditorEnabled( true ); 
-    connect( this, TQT_SIGNAL(removed( const TQString&) ), TQT_SLOT(slotRemoved( const TQString& )) );
+    connect( this, TQ_SIGNAL(removed( const TQString&) ), TQ_SLOT(slotRemoved( const TQString& )) );
 
     if ( !kapp->dcopClient()->isAttached() )
         kapp->dcopClient()->attach();
@@ -396,10 +396,10 @@ bool KonqCombo::eventFilter( TQObject *o, TQEvent *ev )
     // Handle Ctrl+Del/Backspace etc better than the Qt widget, which always
     // jumps to the next whitespace.
     TQLineEdit *edit = lineEdit();
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(edit) ) {
+    if ( o == edit ) {
         int type = ev->type();
         if ( type == TQEvent::KeyPress ) {
-            TQKeyEvent *e = TQT_TQKEYEVENT( ev );
+            TQKeyEvent *e = static_cast<TQKeyEvent*>( ev );
 
             if ( e->key() == Key_Return || e->key() == Key_Enter ) {
                 m_modifier = e->state();
@@ -537,7 +537,7 @@ void KonqCombo::mousePressEvent( TQMouseEvent *e )
 {
     m_dragStart = TQPoint(); // null QPoint
 
-    if ( e->button() == Qt::LeftButton && pixmap( currentItem()) ) {
+    if ( e->button() == TQt::LeftButton && pixmap( currentItem()) ) {
         // check if the pixmap was clicked
         int x = e->pos().x();
         int x0 = TQStyle::visualRect( style().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxEditField ), this ).x();
@@ -548,7 +548,7 @@ void KonqCombo::mousePressEvent( TQMouseEvent *e )
         }
     }
 
-    if ( e->button() == Qt::LeftButton && m_pageSecurity!=KonqMainWindow::NotCrypted ) {
+    if ( e->button() == TQt::LeftButton && m_pageSecurity!=KonqMainWindow::NotCrypted ) {
         // check if the lock icon was clicked
         int x = e->pos().x();
         int x0 = TQStyle::visualRect( style().querySubControlMetrics( TQStyle::CC_ComboBox, this, TQStyle::SC_ComboBoxArrow ), this ).x();
@@ -566,7 +566,7 @@ void KonqCombo::mouseMoveEvent( TQMouseEvent *e )
     if ( m_dragStart.isNull() || currentText().isEmpty() )
         return;
 
-    if ( e->state() & Qt::LeftButton &&
+    if ( e->state() & TQt::LeftButton &&
          (e->pos() - m_dragStart).manhattanLength() >
          TDEGlobalSettings::dndEventDelay() )
     {
@@ -591,7 +591,7 @@ void KonqCombo::slotActivated( const TQString& text )
     applyPermanent();
     m_returnPressed = true;
     emit activated( text, m_modifier );
-    m_modifier = Qt::NoButton;
+    m_modifier = TQt::NoButton;
 }
 
 void KonqCombo::setConfig( TDEConfig *kc )
@@ -731,7 +731,7 @@ void KonqComboListBoxPixmap::paint( TQPainter *painter )
     if ( !text().isEmpty() ) {
         TQString squeezedText = KStringHandler::rPixelSqueeze( text(), listBox()->fontMetrics(), urlWidth );
         painter->drawText( pmWidth, 0, urlWidth + pmWidth, itemHeight, 
-                           Qt::AlignLeft | Qt::AlignTop, squeezedText );
+                           TQt::AlignLeft | TQt::AlignTop, squeezedText );
 
         //painter->setPen( TDEGlobalSettings::inactiveTextColor() );
         squeezedText = KStringHandler::rPixelSqueeze( title, listBox()->fontMetrics(), titleWidth );
@@ -739,7 +739,7 @@ void KonqComboListBoxPixmap::paint( TQPainter *painter )
         font.setItalic( true );
         painter->setFont( font );
         painter->drawText( entryWidth - titleWidth, 0, titleWidth,
-                           itemHeight, Qt::AlignLeft | Qt::AlignTop, squeezedText );
+                           itemHeight, TQt::AlignLeft | TQt::AlignTop, squeezedText );
     }
 }
 
