@@ -176,7 +176,7 @@ void TEScreen::cursorLeft(int n)
 }
 
 /*!
-    Move the cursor left.
+    Move the cursor right.
 
     The cursor will not move beyond the rightmost column.
 */
@@ -188,6 +188,50 @@ void TEScreen::cursorRight(int n)
   cuX = TQMIN(columns-1,cuX+n);
 }
 
+/*!
+    Move the cursor at most n lines next
+*/
+
+void TEScreen::cursorNextLine(int n)
+//=CNL
+{
+	if (n == 0)
+	{
+		n = 1; // Default
+	}
+	cuX = 0;
+	while (n > 0)
+	{
+		if (cuY < lines - 1)
+		{
+			cuY += 1;
+		}
+		n--;
+	}
+}
+
+/*!
+    Move the cursor at most n lines previous
+*/
+
+void TEScreen::cursorPrevLine(int n)
+//=CPL
+{
+	if (n == 0)
+	{
+		n = 1; // Default
+	}
+	cuX = 0;
+	while (n > 0)
+	{
+		if (cuY  > 0)
+		{
+			cuY -= 1;
+		}
+		n--;
+	}
+}
+
 /*!
     Set top and bottom margin.
 */
